@@ -1,5 +1,5 @@
 package Terse;
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 use 5.006;
 use strict;
 use warnings;
@@ -101,7 +101,7 @@ sub run {
 
 	$j->sid = {
 		value => $j->is_logout ? "" : $j->sid,
-		path  => $j->request->uri,
+		path  => $j->{_sid_path} || $j->{_root_path} || "/",
 		secure => !$j->{_insecure_session},
 		samesite => 'none'
 	};
@@ -410,7 +410,7 @@ Terse - Lightweight Web Framework
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
