@@ -33,7 +33,12 @@ sub web {
 			$t->logError('Kaput' . $_[2]);
 		} 
 	);
-}	
+}
+
+sub redirect {
+	my ($self, $t) = @_;
+	$t->redirect('', {req => 'hello_world'});
+}
 
 sub error {
 	$_[1]->logError('test an error', 500);
